@@ -1,7 +1,7 @@
 #######################################################################
 # arules - Mining Association Rules and Frequent Itemsets
 # Copyright (C) 2011-2015 Michael Hahsler, Christian Buchta,
-#			Bettina Gruen and Kurt Hornik
+# 			Bettina Gruen and Kurt Hornik
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -33,8 +33,8 @@
 #' Classes dist, ar_cross_dissimilarity and ar_similarity --- Proximity
 #' Matrices
 #'
-#' Simple classes to represent proximity matrices.  
-#' 
+#' Simple classes to represent proximity matrices.
+#'
 #' For compatibility with
 #' clustering functions in `R`, we represent dissimilarities as the
 #' `S3` class `dist`.  For cross-dissimilarities and similarities, we
@@ -44,7 +44,7 @@
 #'
 #' @name proximity-classes
 #' @family proximity classes and functions
-#' 
+#'
 #' @section Objects from the Class: `dist` objects are the result of
 #' calling the method `dissimilarity()` with one argument or any
 #' `R` function returning a `S3 dist` object.
@@ -64,12 +64,14 @@ setOldClass("dist")
 #' @rdname proximity-classes
 setClass("ar_similarity",
   contains = "matrix",
-  representation(method = "character"))
+  representation(method = "character")
+)
 
 #' @rdname proximity-classes
 setClass("ar_cross_dissimilarity",
   contains = "matrix",
-  representation(method = "character"))
+  representation(method = "character")
+)
 
 
 #' Dissimilarity Matrix Computation for Associations and Transactions
@@ -82,7 +84,7 @@ setClass("ar_cross_dissimilarity",
 #'
 #' @aliases dissimilarity dist
 #' @family proximity classes and functions
-#' 
+#'
 #' @param x the set of elements (e.g., `matrix`, [itemMatrix], [transactions],
 #' [itemsets], [rules]).
 #' @param y `NULL` or a second set to calculate cross dissimilarities.
@@ -192,8 +194,10 @@ setClass("ar_cross_dissimilarity",
 #' ## use affinity to cluster rules
 #' ## Note: we need to supply the transactions (or affinities) from the
 #' ## dataset (sample).
-#' d_affinity <- dissimilarity(rules, method = "affinity",
-#'   args = list(transactions = s))
+#' d_affinity <- dissimilarity(rules,
+#'   method = "affinity",
+#'   args = list(transactions = s)
+#' )
 #' hc <- hclust(d_affinity, method = "ward.D2")
 #' plot(hc, main = "Dendrogram for Rules (Affinity)")
 #'
@@ -201,54 +205,70 @@ setClass("ar_cross_dissimilarity",
 #' assign <- cutree(hc, k = 3)
 #' inspect(rules[assign == 1])
 #'
-setGeneric("dissimilarity",
-  function(x,
-    y = NULL,
-    method = NULL,
-    args = NULL,
-    ...)
-    standardGeneric("dissimilarity"))
+setGeneric(
+  "dissimilarity",
+  function(
+      x,
+      y = NULL,
+      method = NULL,
+      args = NULL,
+      ...) {
+    standardGeneric("dissimilarity")
+  }
+)
 
 #' @rdname dissimilarity
-setMethod("dissimilarity", signature(x = "matrix"),
-  function(x,
-    y = NULL,
-    method = NULL,
-    args = NULL) {
+setMethod(
+  "dissimilarity", signature(x = "matrix"),
+  function(
+      x,
+      y = NULL,
+      method = NULL,
+      args = NULL) {
     ## Compute dissimilarities on binary data
-    
+
     ## make sure the input is a 0-1 matrix or a logical matrix
-    is.zeroone <- function(x)
+    is.zeroone <- function(x) {
       (all(x == 0 | x == 1))
-    
+    }
+
     storage.mode(x) <- "numeric"
-    if (!is.zeroone(x))
+    if (!is.zeroone(x)) {
       stop("x is not a binary matrix (0-1 or logical)!")
-    
+    }
+
     ## cross dissimilarities? Check y
     if (!is.null(y)) {
-      if (!is.matrix(y))
+      if (!is.matrix(y)) {
         stop("'y' not a matrix")
+      }
       storage.mode(y) <- "numeric"
-      if (!is.zeroone(y))
+      if (!is.zeroone(y)) {
         stop("y is not a binary matrix (0-1 or logical)!")
+      }
       cross <- TRUE
-    } else
+    } else {
       cross <- FALSE
-    
-    builtin_methods <- c("affinity",
+    }
+
+    builtin_methods <- c(
+      "affinity",
       "jaccard",
       "matching",
       "dice",
       "cosine",
       "euclidean",
       "pearson",
-      "phi")
-    
-    if (is.null(method))
-      ind <- 2      # Jaccard is standard
-    else if (is.na(ind <- pmatch(tolower(method),
-      tolower(builtin_methods))))
+      "phi"
+    )
+
+    if (is.null(method)) {
+      ind <- 2
+    } # Jaccard is standard
+    else if (is.na(ind <- pmatch(
+      tolower(method),
+      tolower(builtin_methods)
+    ))) {
       stop(
         gettextf(
           "Value '%s' is not a valid abbreviation for a similarity method.",
@@ -256,40 +276,45 @@ setMethod("dissimilarity", signature(x = "matrix"),
         ),
         domain = NA
       )
-    
+    }
+
     method <- builtin_methods[ind]
-    
+
     ## affinity is special!
     if (ind == 1) {
       ## Affinity.
       ## for rules and itemsets we need transactions or affinities
-      
+
       ## given affinities or transactions? Otherwise, calculate!
-      if (!is.null(args$aff))
+      if (!is.null(args$aff)) {
         affinities <- args$aff
-      else if (!is.null(args$trans))
+      } else if (!is.null(args$trans)) {
         affinities <- affinity(args$trans)
-      else
+      } else {
         affinities <- affinity(x)
-      
+      }
+
       ## Normalize transaction incidences by transaction length.
       x <- x / pmax(rowSums(x), 1)
-      
+
       if (!cross) {
         dist <- 1 - stats::as.dist(x %*% affinities %*% t(x))
-      } else{
+      } else {
         y <- y / pmax(rowSums(y), 1)
-        dist <- new("ar_cross_dissimilarity",
-          1 - x %*% affinities %*% t(y))
+        dist <- new(
+          "ar_cross_dissimilarity",
+          1 - x %*% affinities %*% t(y)
+        )
       }
-      
+
       ## Euclidean is special too
     } else if (ind == 6) {
-      if (cross)
+      if (cross) {
         stop("Euclidean cross-distance not implemented.")
-      
+      }
+
       dist <- dist(x, method = "euclidean")
-      
+
       ## Pearson correlation coefficient (Note: cor is calculated
       ##    between columns and we only use pos. correlation)
       ## Phi is the same as pearson
@@ -298,158 +323,169 @@ setMethod("dissimilarity", signature(x = "matrix"),
         ## warnings for zero variance!
         suppressWarnings(cm <- stats::cor(t(x), method = "pearson"))
         ## pairwise complete is very slow
-        #cm <- stats::cor(t(x), method = "pearson",
-        #	  use="pairwise.complete.obs")
+        # cm <- stats::cor(t(x), method = "pearson",
+        # 	  use="pairwise.complete.obs")
         cm[cm < 0 | is.na(cm)] <- 0
         dist <- stats::as.dist(1 - cm)
       } else {
         suppressWarnings(cm <- stats::cor(t(x), t(y), method = "pearson"))
-        #cm <- stats::cor(t(x), t(y), method = "pearson",
-        #	use="pairwise.complete.obs")
+        # cm <- stats::cor(t(x), t(y), method = "pearson",
+        # 	use="pairwise.complete.obs")
         cm[cm < 0 | is.na(cm)] <- 0
         dist <- new("ar_cross_dissimilarity", 1 - cm)
       }
     } else {
-      if (!cross)
+      if (!cross) {
         y <- x
-      
+      }
+
       ## prepare a, b, c, d (response table) for the rest of measures
       ## see: Gower, J. C. and P. Legendre.  1986.  Metric and
       ## Euclidean properties of dissimilarity coefficients.
       ## J. Classif. 3: 5 - 48.
-      #a <- x %*% t(y)
+      # a <- x %*% t(y)
       a <- tcrossprod(x, y)
-      
+
       ## save some memory
-      #b <- x %*% (1 - t(y))
-      #c <- (1 - x) %*% t(y)
-      #d <- ncol(x) - a - b - c
-      
+      # b <- x %*% (1 - t(y))
+      # c <- (1 - x) %*% t(y)
+      # d <- ncol(x) - a - b - c
+
       # even faster code adapted from Leisch (2005): A toolbox for
       # K-centroids cluster analysis, Preprint.
       nx <- nrow(x)
       ny <- nrow(y)
-      
+
       c <- matrix(rowSums(x), nrow = nx, ncol = ny) - a
       b <-
         matrix(rowSums(y),
           nrow = nx,
           ncol = ny,
-          byrow = TRUE) - a
-      
-      #a_b_c <- matrix(rowSums(x), nrow = nx, ncol = ny) +
-      #matrix(rowSums(y), nrow = nx, ncol = ny, byrow = TRUE) - a
-      
-      
+          byrow = TRUE
+        ) - a
+
+      # a_b_c <- matrix(rowSums(x), nrow = nx, ncol = ny) +
+      # matrix(rowSums(y), nrow = nx, ncol = ny, byrow = TRUE) - a
+
+
       if (ind == 2) {
         ## Jaccard == binary (Sneath, 1957)
-        #dist <- dist(as(x, "matrix"), "binary")
-        
+        # dist <- dist(as(x, "matrix"), "binary")
+
         dist <- 1 - a / (a + b + c)
-        #dist <- 1 - (a/a_b_c)
-        
+        # dist <- 1 - (a/a_b_c)
       } else if (ind == 3) {
         ## Matching Coefficient (Sokal and Michener, 1958)
-        
-        #we need d only here
-        #d <- ncol(x) - a_b_c
+
+        # we need d only here
+        # d <- ncol(x) - a_b_c
         d <- ncol(x) - (a + b + c)
-        
+
         dist <- 1 - (a + d) / (a + b + c + d)
-        #dist <- 1 - ((a + d) / (a_b_c + d))
-        
+        # dist <- 1 - ((a + d) / (a_b_c + d))
       } else if (ind == 4) {
         ## Dice Coefficient (Dice, 1945)
         dist <- 1 - 2 * a / (2 * a + b + c)
-        #dist <- 1 - 2 * a / (a + a_b_c)
-        
+        # dist <- 1 - 2 * a / (a + a_b_c)
       } else if (ind == 5) {
         ## Cosine
         dist <- 1 - a / sqrt((a + b) * (a + c))
       }
     }
-    
+
     # in case we divided by zero
     dist[is.nan(dist)] <- 0
-    
+
     if (!cross) {
       # return a S3 "dist" object just add "ar_dissimilarity"
       dist <- stats::as.dist(dist)
       attr(dist, "method") <- method
-      #class(dist) <- c("ar_dissimilarity", class(dist))
+      # class(dist) <- c("ar_dissimilarity", class(dist))
       return(dist)
-      
-    } else{
+    } else {
       # return a S4 "ar_cross_dist" object
       dist <- new("ar_cross_dissimilarity", dist, method = method)
       return(dist)
     }
-    
-  })
+  }
+)
 
 
 #' @rdname dissimilarity
-setMethod("dissimilarity", signature(x = "itemMatrix"),
-  function(x,
-    y = NULL,
-    method = NULL,
-    args = NULL,
-    which = "transactions") {
+setMethod(
+  "dissimilarity", signature(x = "itemMatrix"),
+  function(
+      x,
+      y = NULL,
+      method = NULL,
+      args = NULL,
+      which = "transactions") {
     ## use items?
-    if (is.null(which))
+    if (is.null(which)) {
       which <- "transactions"
+    }
     items <- pmatch(tolower(which), "items", nomatch = 0) == 1
-    
+
     x <- as(x, "matrix")
-    if (items)
+    if (items) {
       x <- t(x)
-    
+    }
+
     if (!is.null(y)) {
       y <- as(y, "matrix")
-      if (items)
+      if (items) {
         y <- t(y)
+      }
     }
-    
+
     dissimilarity(
       x = x,
       y = y,
       method = method,
       args = args
     )
-  })
+  }
+)
 
 #' @rdname dissimilarity
-setMethod("dissimilarity", signature(x = "associations"),
-  function(x,
-    y = NULL,
-    method = NULL,
-    args = NULL,
-    which = "associations") {
-    if (is.null(method))
-      method <- "jaccard"   # Jaccard is standard
-    
+setMethod(
+  "dissimilarity", signature(x = "associations"),
+  function(
+      x,
+      y = NULL,
+      method = NULL,
+      args = NULL,
+      which = "associations") {
+    if (is.null(method)) {
+      method <- "jaccard"
+    } # Jaccard is standard
+
     builtin_methods <- c("gupta", "toivonen")
-    
-    if (!is.na(ind <- pmatch(tolower(method),
-      tolower(builtin_methods)))) {
+
+    if (!is.na(ind <- pmatch(
+      tolower(method),
+      tolower(builtin_methods)
+    ))) {
       method <- builtin_methods[ind]
-      if (!is.null(y))
+      if (!is.null(y)) {
         stop("Cross dissimilarities not implemented for this method!")
+      }
       trans <- args$trans
-      if (is.null(trans))
+      if (is.null(trans)) {
         stop("Transactions needed in args for this method!")
-      
+      }
+
       if (ind == 1) {
-        ##gupta: use tidlist intersection
-        
+        ## gupta: use tidlist intersection
+
         ## FIXME: tidlist operations should be made functions
-        
+
         ## calculate tidlist for rules
         tids <- .associationTidLists(x, trans)
-        
+
         m_X <- sapply(tids, length)
         n <- length(x)
-        
+
         m <- matrix(nrow = n, ncol = n)
         for (i in 1:n) {
           for (j in i:n) {
@@ -458,24 +494,24 @@ setMethod("dissimilarity", signature(x = "associations"),
             m[j, i] <- m[i, j] ## dists are symmetric
           }
         }
-        
+
         dist <- stats::as.dist(m)
         attr(dist, "method") <- method
         return(dist)
-        
-      } else{
+      } else {
         ## toivonen
-        
+
         ## only one RHS allowed
-        if (length(unique(rhs(x))) != 1)
+        if (length(unique(rhs(x))) != 1) {
           stop("Only a single RHS allowed for this method!")
-        
+        }
+
         ## calculate tidlist for rules
         tids <- .associationTidLists(x, trans)
-        
+
         m_X <- sapply(tids, length)
         n <- length(x)
-        
+
         m <- matrix(nrow = n, ncol = n)
         for (i in 1:n) {
           for (j in i:n) {
@@ -484,24 +520,26 @@ setMethod("dissimilarity", signature(x = "associations"),
             m[j, i] <- m[i, j] ## dists are symmetric
           }
         }
-        
+
         dist <- stats::as.dist(m)
         attr(dist, "method") <- method
         return(dist)
-        
       }
     }
-    
-    
+
+
     ## use methods for transactions
-    if (!is.null(y))
+    if (!is.null(y)) {
       y <- items(y)
+    }
     dissimilarity(items(x),
       y,
       method = method,
       args = args,
-      which = which)
-  })
+      which = which
+    )
+  }
+)
 
 
 ## helper to compute tidLists for associations
@@ -509,17 +547,18 @@ setMethod("dissimilarity", signature(x = "associations"),
 .associationTidLists <- function(x, trans) {
   I <- LIST(items(x), decode = FALSE)
   tlists <- LIST(as(trans, "tidLists"), decode = FALSE)
-  
+
   tids <- list()
   for (i in seq_len(length(I))) {
     v <- I[[i]]
     tids[[i]] <- tlists[[v[1]]]
-    if (length(v) > 1)
+    if (length(v) > 1) {
       for (j in 2:length(v)) {
         tids[[i]] <- intersect(tids[[i]], tlists[[v[j]]])
       }
+    }
   }
-  
+
   tids
 }
 
@@ -555,23 +594,31 @@ setMethod("dissimilarity", signature(x = "associations"),
 #'
 #' a <- affinity(s)
 #' image(a)
-setGeneric("affinity",
-  function(x)
-    standardGeneric("affinity"))
+setGeneric(
+  "affinity",
+  function(x) {
+    standardGeneric("affinity")
+  }
+)
 
 
 #' @rdname affinity
-setMethod("affinity", signature(x = "matrix"),
+setMethod(
+  "affinity", signature(x = "matrix"),
   function(x) {
     ## Affinity is basically the Jaccard similarity between items
     new("ar_similarity",
       as.matrix(1 - dissimilarity(t(x), method = "Jaccard")),
-      method = "Affinity")
+      method = "Affinity"
+    )
     ## Fix: S4 as(..., "matrix") does not work
-  })
+  }
+)
 
 #' @rdname affinity
-setMethod("affinity", signature(x = "itemMatrix"),
+setMethod(
+  "affinity", signature(x = "itemMatrix"),
   function(x) {
     affinity(as(x, "matrix"))
-  })
+  }
+)
