@@ -1,5 +1,5 @@
 /*----------------------------------------------------------------------
-  Detect 64 bit architecure
+  Detect 64 bit architecture
   ----------------------------------------------------------------------*/
 
 /*
