@@ -35,9 +35,6 @@ typedef struct {                /* --- a bit matrix --- */
   int **rows;                   /* array of row bit vectors */
   int *buf;                     /* buffer for intersection */
   int *supps;                   /* supports of represented sets */
-  #ifdef BENCH
-  int mem;                      /* memory used during search */
-  #endif
 } BITMAT;                       /* (bit matrix) */
 
 typedef void BMREPFN (int *ids, int cnt, int supp, int *tal,void *data);
@@ -65,9 +62,6 @@ extern int     bm_ones   (BITMAT *bm, int row);
 extern int     bm_allone (BITMAT *bm, int mode, int supp,
                           int min, int max, BMREPFN report, void *data, int tacnt);
 
-#ifndef NDEBUG
-extern void    bm_show   (BITMAT *bm, FILE *file, int transpose);
-#endif
 
 /*----------------------------------------------------------------------
   Preprocessor Definitions
