@@ -121,8 +121,7 @@ static void _count (ISNODE *node, int *set, int cnt, int min)
         node->cnts[i]++;        /* if the counter exists, */
       } }                       /* count the transaction */
     else if (node->chcnt > 0) { /* if there are child nodes */
-/*      vec = (ISNODE**)(node->cnts +node->size); */
-      vec = get_vec(node);
+      vec = isn_vec(node);
       n   = ID(vec[0]);         /* get the child node vector */
       min--;                    /* one item less to the deepest nodes */
       while ((cnt > min) && (*set < n)) {
@@ -183,8 +182,7 @@ static void _countx (ISNODE *node, TATREE *tat, int min)
           node->cnts[i] += tat_cnt(tat_child(tat, k));
       } }                       /* count the transaction */
     else if (node->chcnt > 0) { /* if there are child nodes */
-  /*    vec = (ISNODE**)(node->cnts +node->size); */
-      vec = get_vec(node);
+      vec = isn_vec(node);
       n   = ID(vec[0]);         /* get the child node vector */
       min--;                    /* one item less to the deepest nodes */
       for (k = tat_size(tat); --k >= 0; ) {
@@ -229,8 +227,7 @@ static int _stskip (ISNODE *node)
   if (node->chcnt  == 0) return  0;  /* do not skip new leaves */
   if (node->chcnt  <  0) return -1;  /* skip marked subtrees */
   if (node->offset >= 0)        /* if a pure vector is used */
-/*    vec = (ISNODE**)(node->cnts +node->size);*/
-    vec = get_vec(node);
+    vec = isn_vec(node);
   else                          /* if an identifer map is used */
     vec = (ISNODE**)(node->cnts +node->size +node->size);
   for (r = -1, i = node->chcnt; --i >= 0; )
@@ -257,8 +254,7 @@ static int _check (ISNODE *node, char *marks, int supp)
           marks[n+i] = r = 1;   /* mark items in set that satisfies */
       } }                       /* the minimum support criterion */
     else if (node->chcnt > 0) { /* if there are child nodes */
-/*      vec = (ISNODE**)(node->cnts +node->size); */
-      vec = get_vec(node);
+      vec = isn_vec(node);
       for (i = node->chcnt; --i >= 0; )
         if (vec[i]) r |= _check(vec[i], marks, supp);
     } }                         /* recursively process all children */
@@ -293,8 +289,7 @@ static int _getsupp (ISNODE *node, int *set, int cnt)
     c = node->chcnt & ~F_SKIP;  /* if there are no children, */
     if (c <= 0) return -1;      /* the support is less than minsupp */
     if (node->offset >= 0) {    /* if a pure vector is used */
-/*      vec = (ISNODE**)(node->cnts +node->size); */
-      vec = get_vec(node);
+      vec = isn_vec(node);
       i   = *set++ -ID(vec[0]); /* compute the child vector index and */
       if (i >= c) return -1; }  /* abort if the child does not exist */
     else {                      /* if an identifier map is used */
@@ -330,8 +325,7 @@ static void _clrsupp (ISNODE *node, int *set, int cnt, int supp)
   assert(node && set && (cnt >= 0)); /* check the function arguments */
   while (--cnt > 0) {           /* follow the set/path from the node */
     if (node->offset >= 0) {    /* if a pure vector is used */
-      /* vec = (ISNODE**)(node->cnts +node->size); */
-      vec = get_vec(node);
+      vec = isn_vec(node);
       i   = *set++ -ID(vec[0]);}/* compute the child vector index */
     else {                      /* if an identifier map is used */
       map = node->cnts +(n = node->size);
@@ -413,26 +407,18 @@ static ISNODE* _child (ISTREE *ist, ISNODE *node, int index,
       ist->map[n++] = k;        /* for a full rule and a rule body, */
   }                             /* note the item identifier */
   if (n <= 0) return NULL;      /* if no child is needed, abort */
-#ifdef BENCH                  /* if benchmark version: */
-  ist->nec += n;                /* sum the necessary counters */
-#endif
 
   /* --- decide on node structure --- */
   k = ist->map[n-1] -ist->map[0] +1;
   if    (!ist->memopt) n = k;   /* check the size of a pure vector */
   else if (3*n >= 2*k) n = k;   /* use a pure vector if it is small */
   else                 k = n+n; /* enough, otherwise use an id. map */
-#ifdef BENCH                  /* if benchmark version */
-  ist->cnt   += n;              /* sum the number of counters */
-  ist->bytes += sizeof(ISNODE) +(k-1) *sizeof(int) +8;
-#endif                        /* determine the memory usage */
 
   /* --- create child --- */
-#ifdef ARCH64               /* if 64 bit architecture */
-  curr = (ISNODE*)malloc(sizeof(ISNODE) + ((k&1)?k:(k-1)) *sizeof(int));
-#else
-  curr = (ISNODE*)malloc(sizeof(ISNODE) +(k-1) *sizeof(int));
-#endif                        /* pad to even number of counters */
+  //curr = (ISNODE*)malloc(sizeof(ISNODE) + isn_align(k) *sizeof(int));
+  // alignment is not important yet
+  curr = (ISNODE*)malloc(sizeof(ISNODE) + k *sizeof(int));
+  
   if (!curr) return (void*)-1;  /* create a child node */
   curr->parent = node;          /* set pointer to parent node */
   curr->succ   = NULL;          /* and clear successor pointer */
@@ -592,14 +578,11 @@ ISTREE* ist_create (int itemcnt, double supp, double conf,
   assert((itemcnt >= 0)         /* check the function arguments */
       && (supp >= 0) && (supp <= 1) && (conf >= 0) && (conf <= 1));
 
-  n = itemcnt;                  /* on 32 bit systems, however, */
+  n = itemcnt;                  
 
   /* --- allocate memory --- */ 
-#ifdef ARCH64                 /* if 64 bit architecture */
-  ist = (ISTREE*)malloc(sizeof(ISTREE) +((n&1)?n:(n-1)) *sizeof(char));
-#else                         /* pad counters to even number */
-  ist = (ISTREE*)malloc(sizeof(ISTREE) +(n-1) *sizeof(char));
-#endif                        /* use the number of items directly */
+  ist = (ISTREE*)malloc(sizeof(ISTREE) + n *sizeof(char));
+  
   if (!ist) return NULL;        /* allocate the tree body */
   ist->levels = lvl = (ISNODE**)malloc(BLKSIZE *sizeof(ISNODE*));
   if (!lvl) { free(ist); return NULL; }
@@ -609,7 +592,7 @@ ISTREE* ist_create (int itemcnt, double supp, double conf,
   if (!map) { free(buf); free(lvl); free(ist); return NULL; }
 
   lvl[0] = ist->curr = root =   /* allocate a root node */
-    (ISNODE*)calloc(1, sizeof(ISNODE) +(n-1) *sizeof(int));
+    (ISNODE*)calloc(1, sizeof(ISNODE) + isn_align(n) *sizeof(int));
   if (!root){ free(map); free(buf); free(lvl); free(ist); return NULL; }
 
   /* --- initialize structures --- */
@@ -618,14 +601,6 @@ ISTREE* ist_create (int itemcnt, double supp, double conf,
   ist->supp    = supp; ist->conf  = conf;
   ist->rsdef   = rsdef & IST_BOTH;
   ist->memopt  = memopt;
-#ifdef BENCH                  /* if benchmark version */
-  ist->cnt     = ist->nec   = itemcnt;
-  ist->chcnt   = ist->chnec = 0;
-  ist->bytes   = sizeof(ISTREE) +itemcnt *sizeof(char) +8
-               + BLKSIZE *sizeof(ISNODE*) +8
-               + BLKSIZE *sizeof(int) +8
-               + itemcnt *sizeof(int) +8;
-#endif                        /* initialize the benchmark variables */
   ist_init(ist, 1, EM_NONE, 1); /* initialize rule extraction */
   root->parent = root->succ = NULL;
   root->offset = root->id   = 0;
@@ -715,7 +690,7 @@ int ist_addlvl (ISTREE *ist)
   /* --- enlarge level vector --- */
   if (ist->lvlcnt >= ist->lvlvsz) { /* if the level vector is full */
     n = ist->lvlvsz +BLKSIZE;   /* compute new vector size */
-    p = realloc(ist->levels, n *sizeof(ISNODE*));
+    p = realloc(ist->levels, n * sizeof(ISNODE*));
     if (!p) return -1;          /* enlarge the level vector */
     ist->levels = (ISNODE**)p;  /* and set the new vector */
     p = realloc(ist->buf,    n *sizeof(int));
@@ -742,34 +717,25 @@ int ist_addlvl (ISTREE *ist)
     }                           /* and advance end pointer */
     if (n <= 0) {               /* if no child node was created, */
       (*ndp)->chcnt = F_SKIP; continue; }       /* skip the node */
-#ifdef BENCH                /* if benchmark version */
-    ist->chnec += n;            /* sum the number of necessary */
-#endif                      /* child pointers */
     node = *ndp;                /* decide on the node structure: */
     if (node->offset >= 0) {    /* if a pure counter vector is used, */
       n = ID(last)-ID(frst)+1;  /* always add a pure child vector */
-      i = (node->size -1) *sizeof(int) +n *sizeof(ISNODE*); }
+      i = isn_align(node->size) *sizeof(int) +n *sizeof(ISNODE*); }
     else if (2*n > node->size){ /* if a single id. map is best, */
       n = node->size;           /* only add a child vector */
-      i = (n+n-1) *sizeof(int) +n *sizeof(ISNODE*); }
+      /* this is always even for 64 bit */
+      i = (n+n) *sizeof(int) +n *sizeof(ISNODE*); }
     else {                      /* if two identifier maps are best, */
       i = node->size;           /* add a child vector and a map */
-      i = (i+i-1) *sizeof(int) +n *(sizeof(ISNODE*) +sizeof(int));
+      i = (i+i) *sizeof(int) +n *(sizeof(ISNODE*) +sizeof(int));
     }                           /* get size of additional vectors */
     node = (ISNODE*)realloc(node, sizeof(ISNODE) +i);
     if (!node) { _cleanup(ist); return -1; }
     node->chcnt = n;            /* add a child vector to the node */
-#ifdef BENCH                /* if benchmark version */
-    ist->chcnt += n;            /* sum the number of child pointers */
-    if ((node->offset >= 0) || (node->size == n))
-         ist->bytes += n * sizeof(ISNODE*);
-    else ist->bytes += n *(sizeof(ISNODE*) +sizeof(int));
-#endif                      /* determine the memory usage */
     if ((node != *ndp) && node->parent) {
       last = node->parent;      /* adapt the ref. from the parent */
       if (last->offset >= 0) {  /* if a pure vector is used */
-/*        vec = (ISNODE**)(last->cnts +last->size); */
-        vec = get_vec(last);
+        vec = isn_vec(last);
         vec[(vec[0] != *ndp) ? ID(node) -ID(vec[0]) : 0] = node; }
       else {                    /* if an identifier map is used */
         map = last->cnts +(i = last->size);
@@ -782,8 +748,7 @@ int ist_addlvl (ISTREE *ist)
     }                           /* set the new child pointer */
     *ndp = node;                /* set new (reallocated) node */
     if (node->offset >= 0) {    /* if to use pure vectors */
-/*      vec = (ISNODE**)(node->cnts +node->size); */
-      vec = get_vec(node);
+      vec = isn_vec(node);
       while (--n >= 0) vec[n] = NULL;
       i = ID(frst);             /* get item identifier of first child */
       for (cur = frst; cur; cur = cur->succ) {
@@ -842,8 +807,7 @@ int ist_down (ISTREE *ist, int item)
   c = node->chcnt & ~F_SKIP;    /* if there are no child nodes, */
   if (c <= 0) return -1;        /* abort the function */
   if (node->offset >= 0) {      /* if a pure vector is used */
-/*    vec = (ISNODE**)(node->cnts +node->size); */
-    vec = get_vec(node);
+    vec = isn_vec(node);
     item -= ID(vec[0]);         /* compute index in child node vector */
     if (item >= c) return -1; } /* and abort if there is no child */
   else {                        /* if an identifier map is used */
@@ -1310,49 +1274,3 @@ int ist_hedge (ISTREE *ist, int *hedge, double *supp, double *conf)
 }  /* ist_hedge() */
 
 /*--------------------------------------------------------------------*/
-#ifndef NDEBUG
-
-static void _showtree (ISNODE *node, int level)
-{                               /* --- show subtree */
-  int    i, k;                  /* loop variables, buffer */
-  int    *map, n;               /* identifier map and its size */
-  int    c;                     /* number of children */
-  ISNODE **vec;                 /* vector of child nodes */
-
-  assert(node && (level >= 0)); /* check the function arguments */
-  c = node->chcnt & ~F_SKIP;    /* get the number of children */
-  if      (c <= 0)              /* if there are no children, */
-    vec = NULL;                 /* clear the child vector variable */
-  else if (node->offset >= 0)   /* if a pure vector is used */
-/*    vec = (ISNODE**)(node->cnts +node->size); */
-    vec = get_vec(node);
-  else {                        /* if an identifier map is used */
-    map = node->cnts +(n = node->size);
-    vec = (ISNODE**)(map +n);   /* get id. map and child vector */
-    if (c < n)                  /* if a secondary id. map exists, */
-      map = (int*)(vec +(n = c));      /* get this identifier map */
-  }                             /* get child access variables */
-  for (i = 0; i < node->size; i++) {
-    for (k = level; --k >= 0; ) /* indent and print */
-      printf("   ");            /* item identifier and counter */
-    if (node->offset >= 0) k = node->offset +i;
-    else                   k = node->cnts[node->size +i];
-    printf("%d: %d\n", k, node->cnts[i]);
-    if (!vec) continue;         /* check whether there are children */
-    if (node->offset >= 0) k -= ID(vec[0]);
-    else                   k = _bsearch(map, n, k);
-    if ((k >= 0) && (k < c) && vec[k])
-      _showtree(vec[k], level +1);
-  }                             /* show subtree recursively */
-}  /* _showtree() */
-
-/*--------------------------------------------------------------------*/
-
-void ist_show (ISTREE *ist)
-{                               /* --- show an item set tree */
-  assert(ist);                  /* check the function argument */
-  _showtree(ist->levels[0], 0); /* show nodes recursively */
-  printf("total: %d\n", ist->tacnt);
-}  /* ist_show() */             /* print number of transactions */
-
-#endif
